@@ -20,6 +20,7 @@
 #' @param cdmName Name of the cdm object.
 #' @param cohortTables List of tables that contains cohort, cohort_set and
 #' cohort_attrition can be provided as attributes.
+#' @param cdmVersion Version of the cdm_reference
 #'
 #' @return A `cdm_reference` object.
 #'
@@ -27,7 +28,8 @@
 #'
 cdmFromTables <- function(tables,
                           cdmName,
-                          cohortTables = list()) {
+                          cohortTables = list(),
+                          cdmVersion = NULL) {
   # check input
   assertList(tables, named = TRUE, class = "data.frame")
   assertList(cohortTables, named = TRUE, class = "data.frame")
@@ -40,6 +42,7 @@ cdmFromTables <- function(tables,
     }
   }
   assertCharacter(cdmName, length = 1)
+  assertCharacter(cdmVersion, length = 1, null = T)
 
   src <- newLocalSource()
   for (nm in names(tables)) {
@@ -47,7 +50,9 @@ cdmFromTables <- function(tables,
       dplyr::as_tibble() |>
       newCdmTable(src = src, name = nm)
   }
-  cdm <- newCdmReference(tables = tables, cdmName = cdmName)
+  cdm <- newCdmReference(
+    tables = tables, cdmName = cdmName, cdmVersion = cdmVersion
+  )
 
   for (nm in names(cohortTables)) {
     cdm <- insertTable(cdm = cdm, name = nm, table = cohortTables[[nm]])
