@@ -27,14 +27,15 @@
 #'
 insertTable <- function(cdm, name, table, overwrite = TRUE) {
   assertCharacter(name, length = 1, minNumCharacter = 1, na = TRUE)
+  assertClass(table, "data.frame")
+  table <- dplyr::as_tibble(table)
   UseMethod("insertTable")
 }
 
 #' @export
 insertTable.cdm_reference <- function(cdm, name, table, overwrite = TRUE) {
-  table <- dplyr::collect(table)
   value <- insertTable(
-    cdm = getCdmSource(cdm), name = name, table = table, overwrite = overwrite
+    cdm = cdmSource(cdm), name = name, table = table, overwrite = overwrite
   )
   attr(value, "cdm_reference") <- cdm
   cdm[[name]] <- value
